@@ -25,4 +25,5 @@
 var menudata={children:[
 {text:"Main Page",url:"index.html"},
 {text:"Related Pages",url:"pages.html"},
-{text:"Interfaces",url:"annotated.html"}]}
+{text:"Interfaces",url:"annotated.html"},
+{text:"IDL Files",url:"files.html"}]}
