@@ -1,6 +1,6 @@
 var searchData=
 [
   ['y_0',['y',['../structperipheral_1_1DeviceSlot_1_1Location.html#a3125936997ab07494a845a2e4dbb88dc',1,'peripheral::DeviceSlot::Location::y'],['../structwebcam_1_1Location.html#a28b179b54d18e901e60fdc5d637e7704',1,'webcam::Location::y']]],
-  ['your_20own_20scripts_1',['Writing Your Own Scripts',['../md__2home_2builds_2gitlab_2builds_2kACs-oxc_20_2gitlab_2main_2firmware_2mkdist_2tmp_2build-pdu-pdeb59f5d06466e28d82d2e5158e40480.html#autotoc_md147',1,'']]],
+  ['your_20own_20scripts_1',['Writing Your Own Scripts',['../md_lua-plc.html#autotoc_md147',1,'']]],
   ['yuv_2',['YUV',['../namespacewebcam.html#a3f8536348311babcb8a224b5ae9f59a0afdb909cfcaf5b8736e6835ade30dd0fd',1,'webcam']]]
 ];
