@@ -4,7 +4,7 @@ var searchData=
   ['zcoordmode_1',['ZCoordMode',['../interfaceperipheral_1_1DeviceManager.html#ad123f918ea8b0381a49d02cf860220d0',1,'peripheral::DeviceManager']]],
   ['zcoordmode_2',['zCoordMode',['../structperipheral_1_1DeviceManager_1_1Settings.html#aaa649b8e437a8bb26581e3f053ae3855',1,'peripheral::DeviceManager::Settings']]],
   ['zeroconf_3',['Zeroconf',['../interfacedevsettings_1_1Zeroconf.html',1,'devsettings']]],
-  ['zeroconf_20device_20discovery_4',['Zeroconf Device Discovery',['../md__2home_2builds_2gitlab_2builds_2kACs-oxc_20_2gitlab_2main_2firmware_2mkdist_2tmp_2build-pdu-pfcbab061e3a9385299ee360adb881ed4.html#autotoc_md82',1,'']]],
+  ['zeroconf_20device_20discovery_4',['Zeroconf Device Discovery',['../md_python-json-rpc.html#autotoc_md82',1,'']]],
   ['zigbee_5',['zigbee',['../namespacezigbee.html',1,'']]],
   ['zigbeedevice_6',['ZigbeeDevice',['../interfacezigbee_1_1ZigbeeDevice.html',1,'zigbee']]],
   ['zigbeemanager_7',['ZigbeeManager',['../interfacezigbee_1_1ZigbeeManager.html',1,'zigbee']]],
