@@ -454,8 +454,8 @@ namespace examples {
             try {
                 // Create an agent for performing JSON-RPC objects over HTTP(S)
                 using (Agent agent = new Agent(host)) {
-                    agent.Username = "admin";
-                    agent.Password = "raritan";
+                    agent.Username = username;
+                    agent.Password = password;
                     agent.ServerCertificateValidationCallback = Agent.UnsecureTrustAllCertificatesCallback;
 
                     ObjectProxy pduProxy = null;
