@@ -168,8 +168,6 @@ namespace examples {
                 DumpNumericSensorV3(NumericSensor_3_0_0.StaticCast(proxy), label);
             } else if (typeInfo.IsCallCompatible(NumericSensor_4_0_0.typeInfo)) {
                 DumpNumericSensorV4(NumericSensor_4_0_0.StaticCast(proxy), label);
-            } else if (typeInfo.IsCallCompatible(VoltageMonitoringSensor.typeInfo)) {
-                DumpNumericSensorV4(NumericSensor_4_0_0.StaticCast(proxy), label);
             } else {
                 Console.WriteLine("Unsupported version of NumericSensor interface: " + typeInfo);
             }
@@ -500,8 +498,8 @@ namespace examples {
             try {
                 // Create an agent for performing JSON-RPC objects over HTTP(S)
                 using (Agent agent = new Agent(host)) {
-                    agent.Username = "admin";
-                    agent.Password = "raritan";
+                    agent.Username = username;
+                    agent.Password = password;
                     agent.ServerCertificateValidationCallback = Agent.UnsecureTrustAllCertificatesCallback;
 
                     // Optional: Create an authenticated session; it's also possible
