@@ -245,8 +245,15 @@ class BulkUpdater: # pylint: disable=too-many-instance-attributes
                         lowMemoryUploadOptions["allowLowMemoryDowngrade"] = "1"
                     if self.arguments.allow_untrusted:
                         lowMemoryUploadOptions["allowLowMemoryUntrusted"] = "1"
-
-                firmware.upload(master.agent, self.parsed_fw_file, lowMemoryUploadOptions)
+                try:
+                    firmware.upload(master.agent, self.parsed_fw_file, lowMemoryUploadOptions)
+                except HttpException:
+                    master.state = BulkUpdateStatus.FAILED
+                    self.done_list.append(master)
+                    for link in master.links:
+                        self.done_list.append(link)
+                    self.device_queue.task_done()
+                    continue
                 # wait a bit to prevent JsonRpcErrors on devices with more relayboards
                 time.sleep(5)
                 # list for flattening the structure
